@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2020-08-10'; # DATE
-our $VERSION = '0.601'; # VERSION
+our $DATE = '2020-08-14'; # DATE
+our $VERSION = '0.602'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -11,6 +11,11 @@ use Dist::Zilla::PluginBundle::Filter;
 sub configure {
     my $self = shift;
 
+    # we want these to be loaded early
+    $self->add_plugins(
+        'PERLANCAR::CheckPendingRelease', # before ConfirmRelease
+    );
+
     $self->add_bundle(Filter => {
         -bundle => '@Classic',
         -remove => [qw/PkgVersion PodVersion Readme UploadToCPAN/],
@@ -72,7 +77,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.601 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2020-08-10.
+This document describes version 0.602 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2020-08-14.
 
 =head1 SYNOPSIS
 
